flutter_inappwebview_windows library

Classes

MacOSJavaScriptReplyProxy
MacOSJavaScriptReplyProxyCreationParams
Object specifying creation parameters for creating a MacOSJavaScriptReplyProxy.
WindowsCookieManager
Class that implements a singleton object (shared instance) which manages the cookies used by WebView instances. On Android, it is implemented using CookieManager. On iOS, it is implemented using WKHTTPCookieStore.
WindowsCookieManagerCreationParams
Object specifying creation parameters for creating a WindowsCookieManager.
WindowsFindInteractionController
This class represents the controller used by the WebView to add text-finding capabilities, such as the "Find on page" feature.
WindowsFindInteractionControllerCreationParams
Object specifying creation parameters for creating a WindowsFindInteractionController.
WindowsHeadlessInAppWebView
Class that represents a WebView in headless mode. It can be used to run a WebView in background without attaching an InAppWebView to the widget tree.
WindowsHeadlessInAppWebViewCreationParams
Object specifying creation parameters for creating a WindowsHeadlessInAppWebView.
WindowsHttpAuthCredentialDatabase
Class that implements a singleton object (shared instance) which manages the shared HTTP auth credentials cache. On iOS and MacOS, this class uses the URLCredentialStorage class. On Android, this class has a custom implementation using android.database.sqlite.SQLiteDatabase because WebViewDatabase doesn't offer the same functionalities as iOS URLCredentialStorage.
WindowsHttpAuthCredentialDatabaseCreationParams
Object specifying creation parameters for creating a WindowsHttpAuthCredentialDatabase.
WindowsInAppBrowser
This class represents a native WebView displayed on top of the Flutter App, so it's not integrated into the Flutter widget tree. It uses the native WebView of the platform. The webViewController field can be used to access the PlatformInAppWebViewController API.
WindowsInAppBrowserCreationParams
Object specifying creation parameters for creating a WindowsInAppBrowser.
WindowsInAppWebViewController
Controls a WebView, such as an InAppWebView widget instance, a WindowsHeadlessInAppWebView instance or WindowsInAppBrowser WebView instance.
WindowsInAppWebViewControllerCreationParams
Object specifying creation parameters for creating a WindowsInAppWebViewController.
WindowsInAppWebViewPlatform
Implementation of InAppWebViewPlatform using the WebKit API.
WindowsInAppWebViewWidget
Flutter Widget for adding an inline native WebView integrated in the flutter widget tree.
WindowsInAppWebViewWidgetCreationParams
Object specifying creation parameters for creating a PlatformInAppWebViewWidget.
WindowsLocalStorage
Class that provides methods to manage the JavaScript window.localStorage object. It used by PlatformWebStorage.
WindowsLocalStorageCreationParams
Object specifying creation parameters for creating a WindowsLocalStorage.
WindowsPrintJobController
Class representing a print job eventually returned by PlatformInAppWebViewController.printCurrentPage.
WindowsPrintJobControllerCreationParams
Object specifying creation parameters for creating a WindowsPrintJobController.
WindowsSessionStorage
Class that provides methods to manage the JavaScript window.sessionStorage object. It used by PlatformWebStorage.
WindowsSessionStorageCreationParams
Object specifying creation parameters for creating a WindowsSessionStorage.
WindowsStorage
Class that provides methods to manage the JavaScript Storage object. It is used by PlatformLocalStorage and PlatformSessionStorage.
WindowsStorageCreationParams
Object specifying creation parameters for creating a WindowsStorage.
WindowsWebMessageChannel
The representation of the HTML5 message channels.
WindowsWebMessageChannelCreationParams
Object specifying creation parameters for creating a WindowsWebMessageChannel.
WindowsWebMessageListener
This listener receives messages sent on the JavaScript object which was injected by PlatformInAppWebViewController.addWebMessageListener.
WindowsWebMessageListenerCreationParams
Object specifying creation parameters for creating a WindowsWebMessageListener.
WindowsWebMessagePort
The representation of the HTML5 message ports.
WindowsWebMessagePortCreationParams
Object specifying creation parameters for creating a WindowsWebMessagePort.
WindowsWebStorage
Class that provides access to the JavaScript Web Storage API: window.sessionStorage and window.localStorage. It used by PlatformInAppWebViewController.webStorage.
WindowsWebStorageCreationParams
Object specifying creation parameters for creating a WindowsWebStorage.
WindowsWebStorageManager
Class that implements a singleton object (shared instance) which manages the web storage used by WebView instances. On Android, it is implemented using WebStorage. On iOS and MacOS, it is implemented using WKWebsiteDataStore.default().
WindowsWebStorageManagerCreationParams
Object specifying creation parameters for creating a WindowsWebStorageManager.
WindowsWebViewEnvironment
Controls a WebView Environment used by WebView instances.
WindowsWebViewEnvironmentCreationParams
Object specifying creation parameters for creating a WindowsWebViewEnvironment.